==> fet_5.7.0.orig.tar.gz: fet-5.7.0/src/interface/modifyconstraintactivityendsstudentsdayform.h <==
/***************************************************************************
                          modifyconstraintactivityendsstudentsdayform.h  -  description
                             -------------------
    begin                : Sept 14, 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTACTIVITYENDSSTUDENTSDAYFORM_H
#define MODIFYCONSTRAINTACTIVITYENDSSTUDENTSDAYFORM_H

#include "modifyconstraintactivityendsstudentsdayform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class ModifyConstraintActivityEndsStudentsDayForm : public ModifyConstraintActivityEndsStudentsDayForm_template  {
public:
	ConstraintActivityEndsStudentsDay* _ctr;

	ModifyConstraintActivityEndsStudentsDayForm(ConstraintActivityEndsStudentsDay* ctr);
	~ModifyConstraintActivityEndsStudentsDayForm();

	void updateActivitiesComboBox();

	void constraintChanged();
	void ok();
	void cancel();

	bool filterOk(Activity* a);
	void filterChanged();
	
private:
	//the id's of the activities listed in the activities combo
	QList<int> activitiesList;

};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/modifyconstraintactivityendsstudentsdayform.h <==
/***************************************************************************
                          modifyconstraintactivityendsstudentsdayform.h  -  description
                             -------------------
    begin                : Sept 14, 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTACTIVITYENDSSTUDENTSDAYFORM_H
#define MODIFYCONSTRAINTACTIVITYENDSSTUDENTSDAYFORM_H

#include "ui_modifyconstraintactivityendsstudentsdayform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class ModifyConstraintActivityEndsStudentsDayForm : public QDialog, Ui::ModifyConstraintActivityEndsStudentsDayForm_template  {
	Q_OBJECT
public:
	ConstraintActivityEndsStudentsDay* _ctr;

	ModifyConstraintActivityEndsStudentsDayForm(ConstraintActivityEndsStudentsDay* ctr);
	~ModifyConstraintActivityEndsStudentsDayForm();

	void updateActivitiesComboBox();

	bool filterOk(Activity* a);

public slots:
	void constraintChanged();
	void ok();
	void cancel();

	void filterChanged();
	
private:
	//the id's of the activities listed in the activities combo
	QList<int> activitiesList;

};

#endif
